@@ -416,7 +416,7 @@ int key_I_callback(void *data)
  */
 int key_V_callback(void *data)
 {
-	gui_click_video_capture_button(data);
+	gui_click_video_capture_button();
 
 	if(debug_level > 1)
 		printf("GUVCVIEW: V key pressed\n");
@@ -1013,6 +1013,12 @@ void *capture_loop(void *data)
 	render_set_verbosity(debug_level);
 
 	render_set_crosshair_color(my_config->crosshair_color);
+	/*make sure we are not over the frame limits*/
+	if(my_config->crosshair_size > v4l2core_get_frame_width(my_vd))
+		my_config->crosshair_size = v4l2core_get_frame_width(my_vd);
+	if(my_config->crosshair_size > v4l2core_get_frame_height(my_vd))
+		my_config->crosshair_size = v4l2core_get_frame_height(my_vd);
+	render_set_crosshair_size(my_config->crosshair_size);
 
 	if(render_init(
 		render,
@@ -1047,7 +1053,7 @@ void *capture_loop(void *data)
 	if(my_options->photo_timer > 0)
 	{
 		my_photo_timer = NSEC_PER_SEC * my_options->photo_timer;
-		my_last_photo_time = v4l2core_time_get_timestamp(my_vd); /*timer count*/
+		my_last_photo_time = v4l2core_time_get_timestamp(); /*timer count*/
 	}
 
 	if(my_options->photo_npics > 0)
@@ -1304,16 +1310,16 @@ void *capture_loop(void *data)
 /*
  * start the encoder thread
  * args:
- *   data - pointer to user data
+ *   none
  *
  * asserts:
  *   none
  *
  * returns: error code
  */
-int start_encoder_thread(void *data)
+int start_encoder_thread()
 {
-	int ret = __THREAD_CREATE(&encoder_thread, encoder_loop, data);
+	int ret = __THREAD_CREATE(&encoder_thread, encoder_loop, NULL);
 
 	if(ret)
 		fprintf(stderr, "GUVCVIEW: encoder thread creation failed (%i)\n", ret);
